from eve.utils import config
import jwt


def verify_token(token, secret, issuer, method=None, audiences=None, allowed_roles=None):
    # Try to decode token with each allowed audience
    def decode(audience=None):
        return jwt.decode(token, key=secret, issuer=issuer, audience=audience)

    if not audiences:
        try:
            payload = decode()
        except Exception:
            return (False, None, None, None)
    else:
        for audience in audiences:
            try:
                payload = decode(audience)
            except jwt.InvalidAudienceError:
                continue
            except Exception:
                return (False, None, None, None)
            else:
                break  # this skips the for/else clause
        else:
            return (False, None, None, None)

    account_id = payload.get('sub')  # Get account id
    roles = None

    # Check scope is configured and add append it to the roles
    if config.JWT_SCOPE_CLAIM and payload.get(config.JWT_SCOPE_CLAIM):
        scope = payload.get(config.JWT_SCOPE_CLAIM)
        # Viewers can only read
        if scope == 'viewer' and method not in ['GET', 'HEAD']:
            return (False, payload, account_id, None)
        roles = ['scope:%s' % scope]

    # If roles claim is defined, gather roles from the token
    if config.JWT_ROLES_CLAIM:
        roles = payload.get(config.JWT_ROLES_CLAIM, []) + (roles or [])

    # Check roles if scope or role claim is set
    if allowed_roles and roles is not None:
        if not any(role in roles for role in allowed_roles):
            return (False, payload, account_id, roles)

    return (True, payload, account_id, roles)



#!/usr/bin/env python

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

with open('README.rst', 'r') as f:
    readme = f.read()

setup(
    name='eve-auth-jwt-fork',
    version='1.2.1',
    description='Eve JWT authentication, rs/eve-auth-jwt\'s fork.',
    long_description=readme,
    author='Olivier Poitrey',
    author_email='rs@dailymotion.com',
    url='https://github.com/xdtianyu/eve-auth-jwt',
    keywords=['eve', 'api', 'rest', 'oauth', 'auth', 'jwt'],
    packages=['eve_auth_jwt'],
    package_dir={'eve_auth_jwt': 'eve_auth_jwt'},
    install_requires=['eve>=0.7.5', 'pyjwt==1.7.1', 'cryptography>=2.5'],
    test_suite='test',
    tests_require=['flake8'],
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Environment :: No Input/Output (Daemon)',
        'Intended Audience :: Developers',
        'Intended Audience :: Telecommunications Industry',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Unix',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: HTTP Servers',
        'Topic :: Security',
    ]
)
